<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Styl wskaźnika</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Tryb modny</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Tryb klasyczny</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Tryb wyśrodkowany</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Pozycja</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Inteligentne ukrywanie</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Ustawienia doku</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>